# AUTOGENERATED BY NBDEV! DO NOT EDIT!

__all__ = ["index", "modules", "custom_doc_links", "git_url"]

index = {"size": "00_core.ipynb",
         "family": "00_core.ipynb",
         "copy_func": "00_core.ipynb",
         "patch_to": "00_core.ipynb",
         "patch": "00_core.ipynb",
         "InterpFunction": "00_core.ipynb",
         "RedirectStdStreams": "00_core.ipynb",
         "devnull": "00_core.ipynb",
         "from_values": "00_core.ipynb",
         "array_wrap": "00_core.ipynb",
         "mapsolve": "00_core.ipynb",
         "euler": "00_core.ipynb",
         "rk2": "00_core.ipynb",
         "rk4": "00_core.ipynb",
         "rkwrapper": "00_core.ipynb",
         "rk45": "00_core.ipynb",
         "simfunc": "00_core.ipynb",
         "phase_plot": "00_core.ipynb",
         "vector_field": "00_core.ipynb",
         "Component": "00_core.ipynb",
         "numpy_functions": "00_core.ipynb",
         "Simulation": "00_core.ipynb",
         "repeat": "00_core.ipynb",
         "model": "00_core.ipynb",
         "mse_from_sim": "00_core.ipynb",
         "Storage": "00_core.ipynb",
         "particle": "00_core.ipynb",
         "swarm": "00_core.ipynb",
         "pso_fit_sim": "00_core.ipynb",
         "explore_parameters": "00_core.ipynb",
         "histogram": "01_mcmc.ipynb",
         "corner": "01_mcmc.ipynb",
         "timeit": "01_mcmc.ipynb",
         "time2str": "01_mcmc.ipynb",
         "greek": "01_mcmc.ipynb",
         "lognchoosek": "01_mcmc.ipynb",
         "loguniformpdf": "01_mcmc.ipynb",
         "logjeffreyspdf": "01_mcmc.ipynb",
         "logexponpdf": "01_mcmc.ipynb",
         "logcauchypdf": "01_mcmc.ipynb",
         "loghalfcauchypdf": "01_mcmc.ipynb",
         "loghalfnormalpdf": "01_mcmc.ipynb",
         "lognormalpdf": "01_mcmc.ipynb",
         "logbetapdf": "01_mcmc.ipynb",
         "loglognormalpdf": "01_mcmc.ipynb",
         "Normal": "01_mcmc.ipynb",
         "Exponential": "01_mcmc.ipynb",
         "Uniform": "01_mcmc.ipynb",
         "Jeffreys": "01_mcmc.ipynb",
         "HalfCauchy": "01_mcmc.ipynb",
         "HalfNormal": "01_mcmc.ipynb",
         "LogNormal": "01_mcmc.ipynb",
         "Cauchy": "01_mcmc.ipynb",
         "Beta": "01_mcmc.ipynb",
         "lnprior_function": "01_mcmc.ipynb",
         "MCMCModel": "01_mcmc.ipynb",
         "MCMCModelReg": "01_mcmc.ipynb"}

modules = ["core.py",
           "mcmc.py"]

doc_url = "https://bblais.github.io/pyndamics3/"

git_url = "https://github.com/bblais/pyndamics3/tree/master/"

def custom_doc_links(name): return None
